@@ -119,11 +119,11 @@ KERNEL_SATISFY="linux-image-cloud-$KERNEL_ARCH | linux-image-$KERNEL_ARCH | linu
 INITRD_SATISFY="initramfs-tools | linux-initramfs-tool"
 
 if affected_by_1079443 --maybe; then
-	target_apt_get --yes satisfy "$@" "$INITRD_SATISFY"
+	target_apt_get --yes satisfy "$INITRD_SATISFY"
 	if affected_by_1079443; then
 		work_around_1079443
 	fi
-	target_apt_get --yes satisfy "$@" "$KERNEL_SATISFY"
+	target_apt_get --yes satisfy "$KERNEL_SATISFY"
 else
-	target_apt_get --yes satisfy "$@" "$KERNEL_SATISFY" "$INITRD_SATISFY"
+	target_apt_get --yes satisfy "$KERNEL_SATISFY" "$INITRD_SATISFY"
 fi
